@@ -12,7 +12,8 @@ def wait_pipe_len(sock, expected, timeout=10):
     now = time.time()
     later = now + timeout
     while time.time() < later and len(sock.pipes) != expected:
-        time.sleep(0.002)
-    return len(sock.pipes) == expected
-
-
+        time.sleep(0.0005)
+    if len(sock.pipes) != expected:
+        raise TimeoutError(
+            f"Waiting for {expected} pipes, but have {len(sock.pipes)} pipes"
+        )
